@@ -281,45 +281,53 @@ int
 main (int argc, char **argv)
 {
         GnomeClient *client;
+        GnomeClientFlags flags;
+        gchar *session_args[2];
         int token, init_results;
-        char *init_argv[3] = {NULL, "--init-session-settings", NULL};
-        
-        init_argv[0] = argv[0];
 
-        bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-        textdomain (PACKAGE);
+	init_results = gnome_capplet_init("keyboard-properties", VERSION,
+					  argc, argv, NULL, 0, NULL);
+	if (init_results < 0) {
+                g_warning ("an initialization error occurred while "
+			   "starting 'keyboard-properties-capplet'.\n"
+                           "aborting...\n");
+                exit (1);
+	}
 
-        init_results = gnome_capplet_init ("keyboard-properties",
-                                           VERSION, argc, argv, NULL, 0, NULL);
+	client = gnome_master_client ();
+	flags = gnome_client_get_flags(client);
 
-        client = gnome_master_client();
+	if (flags & GNOME_CLIENT_IS_CONNECTED) {
+		token = gnome_startup_acquire_token("GNOME_KEYBOARD_PROPERTIES",
+				                  gnome_client_get_id(client));
 
-        if(client) {
-                gnome_client_set_restart_command(client, 2, init_argv);
-                gnome_client_set_restart_style(client, GNOME_RESTART_ANYWAY);
-                gnome_client_flush(client);
+		if (token) {
+			session_args[0] = argv[0];
+			session_args[1] = "--init-session-settings";
+			session_args[2] = NULL;
+			gnome_client_set_priority (client, 20);
+			gnome_client_set_restart_style (client, 
+							GNOME_RESTART_ANYWAY);
+			gnome_client_set_restart_command (client, 2, 
+							  session_args);
+		}
+		else 
+			gnome_client_set_restart_style (client, 
+							GNOME_RESTART_NEVER);
+
+                gnome_client_flush (client);
         }
+	else
+		token = 1;
 
-        switch(init_results) {
-        case -1:
-                return 1;
-        case 1:
-                if(client && gnome_client_get_previous_id(client)) {
-                        token = gnome_startup_acquire_token("GNOME_KEYBOARD_PROPERTIES",
-                                                            gnome_client_get_id(client));
-                } else
-                        token = 1;
+        keyboard_read ();	
 
-                if(token) {
-                        keyboard_read();
-                        keyboard_apply();
-                }
+        if(token) 
+                keyboard_apply ();
 
-                return 0;
-                break;
-        default: break;
-        }
-        keyboard_read ();
-        keyboard_setup();
-        capplet_gtk_main ();
+	if (init_results != 1) {
+		keyboard_setup ();
+	        capplet_gtk_main ();
+	}
+        return 0;
 }
