@@ -50,14 +50,15 @@ get_saver_frame ()
         
         ignore_changes = TRUE;
 
+        setup_label = gtk_label_new (_("Settings..."));
+        setup_button = gtk_button_new ();
+
 	swindow = gtk_scrolled_window_new (NULL, NULL);
         gtk_widget_set_usize (swindow, 150, -1 );
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (swindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (swindow), get_and_set_mode());
         gtk_box_pack_start (GTK_BOX (vbox), swindow, TRUE, TRUE, 0);
 
-        setup_label = gtk_label_new (_("Settings..."));
-        setup_button = gtk_button_new ();
         gnome_widget_add_help (setup_button, _("Pressing this button will popup a dialog"\
                                                "box that will help you setup the current screensaver."));
         gtk_container_add (GTK_CONTAINER (setup_button), setup_label);
@@ -192,64 +193,86 @@ int
 main (int argc, char **argv)
 {
         GnomeClient *client = NULL;
-        gchar *temp;
+        GnomeClientFlags flags;
         gchar *session_args[2];
-        int token, init_results;
+        gint token, init_results;
 
         bindtextdomain (PACKAGE, GNOMELOCALEDIR);
         textdomain (PACKAGE);
 
-        init_results = gnome_capplet_init ("screensaver-properties",
-                                           VERSION, argc, argv, NULL, 0, NULL);
-
-        client = gnome_master_client ();
-        if(client) {
-                session_args[0] = "screensaver-properties-capplet";
-                session_args[1] = "--init-session-settings";
-                session_args[2] = NULL;
-                gnome_client_set_restart_style (client, GNOME_RESTART_ANYWAY);
-                gnome_client_set_restart_command (client, 2, session_args);
-        }
-
-        switch (init_results) {
-        case -1:
-                g_warning ("an initialization error occurred while starting 'screensaver-properties-capplet'.\n"
+	init_results = gnome_capplet_init("screensaver-properties", VERSION,
+					  argc, argv, NULL, 0, NULL);
+	if (init_results < 0) {
+                g_warning ("an initialization error occurred while "
+			   "starting 'screensaver-properties-capplet'.\n"
                            "aborting...\n");
                 exit (1);
-        case 1:
-                if(client && gnome_client_get_previous_id(client)) {
-                        token = gnome_startup_acquire_token("GNOME_MOUSE_PROPERTIES",
-                                                            gnome_client_get_id(client));
-                } else
-                        token = 1;
+	}
 
-                if(token) {
-                        /* session initialization */
-                        /* HAH! it's ok to leak memory here 'cuz we exit right away */
-                        temp = g_copy_strings (gnome_config_get_string ("/Screensaver/Default/command=xscreensaver"),
-                                               " >/dev/null 2>&1", NULL);
-                        g_print ("%s\n",temp);
-                        token = gnome_execute_shell(getenv("HOME"),
-                                            "xscreensaver-command -exit >/dev/null 2>&1");
-                        waitpid(token, &token, 0);
+	client = gnome_master_client ();
+	flags = gnome_client_get_flags(client);
 
-                        gnome_execute_shell(getenv("HOME"), temp);
-                }
-                return 0;
-        default:
+	if (flags & GNOME_CLIENT_IS_CONNECTED) {
+		token = gnome_startup_acquire_token("GNOME_SCREENSAVER_PROPERTIES",
+				                  gnome_client_get_id(client));
+
+		if (token) {
+			session_args[0] = argv[0];
+			session_args[1] = "--init-session-settings";
+			session_args[2] = NULL;
+			gnome_client_set_priority (client, 20);
+			gnome_client_set_restart_style (client, 
+							GNOME_RESTART_ANYWAY);
+			gnome_client_set_restart_command (client, 2, 
+							  session_args);
+		}
+		else 
+			gnome_client_set_restart_style (client, 
+							GNOME_RESTART_NEVER);
+
+                gnome_client_flush (client);
+        }
+	else
+		token = 1;
+
+        if(token) {
+                gchar *command, *r_command;
+                gint pid;
+
+                command = gnome_config_get_string ("/Screensaver/Default/command=xscreensaver -no-splash");
+                r_command = g_copy_strings (command, " >/dev/null 2>&1", NULL);
+                g_print ("Screen saver command: %s\n",r_command);
+                pid = gnome_execute_shell(getenv("HOME"),
+                                          "xscreensaver-command"
+                                          " -exit >/dev/null 2>&1");
+                waitpid(pid, &pid, 0);
+
+                gnome_execute_shell(getenv("HOME"), r_command);
+                g_free (command);
+                g_free (r_command);
         }
 
-        screensaver_load ();
-	screensaver_setup();
-        signal (SIGCHLD, sig_child);
-        gtk_signal_connect(GTK_OBJECT(capplet), "destroy", GTK_SIGNAL_FUNC(destroy_callback), NULL);
-        gtk_signal_connect (GTK_OBJECT (capplet), "try", GTK_SIGNAL_FUNC (try_callback), NULL);
-        gtk_signal_connect (GTK_OBJECT (capplet), "revert", GTK_SIGNAL_FUNC (revert_callback), NULL);
-        gtk_signal_connect (GTK_OBJECT (capplet), "cancel", GTK_SIGNAL_FUNC (revert_callback), NULL);
-        gtk_signal_connect (GTK_OBJECT (capplet), "ok", GTK_SIGNAL_FUNC (ok_callback), NULL);
-        gtk_signal_connect (GTK_OBJECT (monitor), "expose_event", (GtkSignalFunc) list_expose_callback, sd);  /* disabled for now */
-        sd = NULL;
+	if (init_results != 1) {
+                screensaver_load ();
+                screensaver_setup();
+                signal (SIGCHLD, sig_child);
+                gtk_signal_connect(GTK_OBJECT(capplet), "destroy", 
+                                   GTK_SIGNAL_FUNC(destroy_callback), NULL);
+                gtk_signal_connect (GTK_OBJECT (capplet), "try", 
+                                    GTK_SIGNAL_FUNC (try_callback), NULL);
+                gtk_signal_connect (GTK_OBJECT (capplet), "revert", 
+                                    GTK_SIGNAL_FUNC (revert_callback), NULL);
+                gtk_signal_connect (GTK_OBJECT (capplet), "cancel", 
+                                    GTK_SIGNAL_FUNC (revert_callback), NULL);
+                gtk_signal_connect (GTK_OBJECT (capplet), "ok", 
+                                    GTK_SIGNAL_FUNC (ok_callback), NULL);
+                gtk_signal_connect (GTK_OBJECT (monitor), "expose_event", 
+                                    GTK_SIGNAL_FUNC (list_expose_callback),
+                                    sd);  /* disabled for now */
+                sd = NULL;
 
-        capplet_gtk_main ();
-	return 0;
+	        capplet_gtk_main ();
+	}
+        return 0;
 }
+
