@@ -60,81 +60,61 @@ static void reload_esd_samples(const char *config_path);
 static void reload_all_esd_samples(void);
 
 int
-main(int argc,
-     char *argv[])
+main(int argc, char *argv[])
 {
-    SoundProps *sound_properties;
-    int init_ret;
     GnomeClient *client;
-    char *init_argv[3] = {NULL, "--init-session-settings", NULL};
+    GnomeClientFlags flags;
+    gchar *session_args[2];
+    int token, init_results;
+    SoundProps *sound_properties;
 
-    init_argv[0] = argv[0];
+	init_results = gnome_capplet_init("sound-properties", VERSION,
+					  argc, argv, NULL, 0, NULL);
 
-    bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-    textdomain (PACKAGE);
+	if (init_results < 0) {
+                g_warning ("an initialization error occurred while "
+                           "starting 'sound-properties-capplet'.\n"
+                           "aborting...\n");
+                exit (1);
+	}
 
-    init_ret =
-        gnome_capplet_init ("sound-properties", VERSION,
-                            argc, argv, NULL, 0, NULL);
+	client = gnome_master_client ();
+	flags = gnome_client_get_flags(client);
 
-    client = gnome_master_client();
+	if (flags & GNOME_CLIENT_IS_CONNECTED) {
+		token = gnome_startup_acquire_token("GNOME_SOUND_PROPERTIES",
+				                  gnome_client_get_id(client));
 
-    if(client) {
-        gnome_client_set_restart_command(client, 2, init_argv);
-        gnome_client_set_restart_style(client, GNOME_RESTART_ANYWAY);
-        gnome_client_flush(client);
-    }
+		if (token) {
+			session_args[0] = argv[0];
+			session_args[1] = "--init-session-settings";
+			session_args[2] = NULL;
+			gnome_client_set_priority (client, 20);
+			gnome_client_set_restart_style (client, 
+							GNOME_RESTART_ANYWAY);
+			gnome_client_set_restart_command (client, 2, 
+							  session_args);
+		}
+		else 
+			gnome_client_set_restart_style (client, 
+							GNOME_RESTART_NEVER);
 
-    switch(init_ret) {
-    case -1:
-        return 1;
-        break;
-    case 1:
-        {
-            int token, esdpid;
-            static const char *esd_cmdline[] = {"esd", NULL};
-            char *tmpargv[3];
-
-            if(client && gnome_client_get_previous_id(client)) {
-                token = gnome_startup_acquire_token("GNOME_SOUND_PROPERTIES",
-                                                    gnome_client_get_id(client));
-            } else
-                token = 1;
-            
-            if(!token)
-                return 0;
-            
-            if(gnome_config_get_bool("/sound/system/settings/start_esd=true")) {
-                char argbuf[32];
-                
-                esdpid = gnome_execute_async(NULL, 1, (char **)esd_cmdline);
-                g_snprintf(argbuf, sizeof(argbuf), "%d", esdpid);
-                tmpargv[0] = "kill";
-                tmpargv[1] = argbuf;
-                tmpargv[2] = NULL;
-
-                if(client)
-                    gnome_client_set_shutdown_command(client, 2, tmpargv);
-
-                sleep(1); /* lame... */
-                gnome_sound_init(NULL); /* Call it again so it will connect */
-                if(gnome_sound_connection < 0)
-                    g_warning("esd didn't start up!");
-                else if(gnome_config_get_bool("/sound/system/settings/event_sounds=true")) {
-                    reload_all_esd_samples();
-                }
-            }
+        gnome_client_flush (client);
         }
-        return 0;
+	else
+		token = 1;
 
-    default:
-        break;
+    /* gnome-session now manages the starting and stopping of esd. */
+
+    if(token && gnome_sound_connection >= 0) {
+        if (gnome_config_get_bool("/sound/system/settings/event_sounds=true"))
+            reload_all_esd_samples();
     }
 
-    sound_properties = sound_properties_create();
-    
-    capplet_gtk_main();
-
+	if (init_results != 1) {
+        sound_properties = sound_properties_create();
+        capplet_gtk_main ();
+	}
     return 0;
 }
 
