@@ -193,7 +193,7 @@ void ok_button_callback(GtkWidget *widget, gpointer data)
 {
         GtkStyle *style;
         node_data *nd = (node_data *) data;
-        style = gtk_widget_get_style (GTK_WIDGET (nd->node));
+        style = gtk_widget_get_style (GTK_WIDGET (nd->ctree));
 
         GNOME_capplet_ok (nd->capplet,nd->id, &ev);
         close_capplet (widget, data);
@@ -203,7 +203,7 @@ void cancel_button_callback(GtkWidget *widget, gpointer data)
 {
         GtkStyle *style;
         node_data *nd = (node_data *) data;
-        style = gtk_widget_get_style (GTK_WIDGET (nd->node));
+        style = gtk_widget_get_style (GTK_WIDGET (nd->ctree));
 
         GNOME_capplet_cancel (nd->capplet,nd->id, &ev);
         close_capplet (widget, data);
