@@ -20,7 +20,7 @@ GdkBitmap *mask2;
 GdkBitmap *mask3;*/
 
 extern gchar *init_cap;
-extern GtkWidget *status_bar;
+extern GnomeAppBar *status_bar;
 
 gint button_press (GtkCTree *ctree, GdkEventButton *event, gpointer data)
 {
@@ -35,14 +35,14 @@ static void
 init_tree_handler (GtkWidget *ctree, GdkEvent *event, node_data *data)
 {
         gtk_signal_disconnect_by_data (GTK_OBJECT (ctree), data);
-        gtk_statusbar_pop (GTK_STATUSBAR (status_bar), 1);
+        gnome_appbar_pop (GNOME_APPBAR(status_bar));
         if (data->gde->comment)
-                gtk_statusbar_push (GTK_STATUSBAR (status_bar), 1, (data->gde->comment));
+                gnome_appbar_push (GNOME_APPBAR (status_bar), (data->gde->comment));
         else
-                gtk_statusbar_push (GTK_STATUSBAR (status_bar), 1, (data->gde->name));
+                gnome_appbar_push (GNOME_APPBAR (status_bar), (data->gde->name));
         launch_capplet (data);
 }
-compare_last_dir (gchar *first, gchar *second)
+gint compare_last_dir (gchar *first, gchar *second)
 {
         gboolean retval;
         gchar *temp1;
@@ -295,11 +295,11 @@ selected_row_callback (GtkWidget *widget, GtkCTreeNode *node, gint column)
         
         data = (node_data *) gtk_ctree_node_get_row_data (GTK_CTREE (widget),node);
         gde = (GnomeDesktopEntry *)data->gde; 
-        gtk_statusbar_pop (GTK_STATUSBAR (status_bar), 1);
+        gnome_appbar_pop (GNOME_APPBAR (status_bar));
         if (gde->comment)
-                gtk_statusbar_push (GTK_STATUSBAR (status_bar), 1, (gde->comment));
+                gnome_appbar_push (GNOME_APPBAR (status_bar), (gde->comment));
         else
-                gtk_statusbar_push (GTK_STATUSBAR (status_bar), 1, (gde->name));
+                gnome_appbar_push (GNOME_APPBAR (status_bar), (gde->name));
 
         if (event) //&& event->type == GDK_2BUTTON_PRESS)
                 launch_capplet (data);
